"""Flight search CLI - Search Google Flights from the command line."""

from .search import search_flights, SearchResult, Flight

__all__ = ["search_flights", "SearchResult", "Flight"]
__version__ = "0.1.0"
